%Function modeling FSPM machines by the use of air gap permeanvces,
%infinaltly premeable stator and rotor steel no fringing effects are
%assumed

%s_teeth=12;             %number of stator poles
%s_scaling=1.0;          %scaling factor of stator teeth vs base tooth width
%
%r_teeth=10;             %number of rotor teeth
%r_scaling=1.4;          %scaling factor of rotor teeth vs base tooth width
%
%base=15e-3;             %base tooth with (width of rotor and stator teeth, magnets and winding slots)
%m_length=2;             %machine length in #base
%airgap=1e-3;            %air gap length
%magnet_length=base*3;   %length of magnets radially
%Br=1.2;                 %magnent remanance flux


%tann                    %avreage flux density in stator tooth number one
%coil                    %coil(#,x)= flux in tooth # for step number x;

function [coil tann] = lumped_parameter(s_teeth,r_teeth,s_scaling,r_scaling,airgap,base,m_length,magnet_length,Br)

my_0=4*pi*1e-7; %my0



Am=(magnet_length)*(base*m_length);%magnet area
lm=base*(2-s_scaling); %magnet length
Ym=my_0*Am/lm; %magnet permeability

phi_r=Br*Am;

stator=0:base*2:base*(4*(s_teeth)-1);   %middle of stator teeth


O=base*4*s_teeth;
base_rotor=-O/r_teeth:O/r_teeth:O/r_teeth*r_teeth;     %middle if rotor teeth




min_slot=min(base*[r_scaling s_scaling]); %the smallest tooth width


step=0;
for displasement=0:0.02*base:O/r_teeth-0.02*base %moving the rotor
step=step+1;

    rotor=base_rotor+displasement;
    i=0;
    Y=inf(1,length(stator));
    for s_tooth=stator
        i=i+1;
        gap_w=0;
        for r_tooth=rotor   %calculation of stator/rotor air gap width for use in reluctance calculations 
            tmp=abs(s_tooth-r_tooth)-base*abs(r_scaling-s_scaling)/2;
            if tmp<0
                gap_w=min_slot;
            elseif tmp<min_slot
                gap_w=min_slot-tmp;
            end
        end
        R_air=airgap/(gap_w*base*m_length*my_0);
        Y(i)=1/R_air; %admittance of different stator/rotor air gaps 

    end

    %setting up Y matrix
    for counter=2:(length(Y)/2-1)
        Ymat(counter,counter)=Y(2*counter-1)+Y(2*counter)+2*Ym;
        Ymat(counter,counter+1)=-Ym;
        Ymat(counter,counter-1)=-Ym;
    end
    Ymat(1,1)=Y(2*1-1)+Y(2*1)+2*Ym;
    Ymat(1,1+1)=-Ym;
    Ymat(length(Y)/2,length(Y)/2)=Y(length(Y)-1)+Y(length(Y))+2*Ym;
    Ymat(length(Y)/2,length(Y)/2-1)=-Ym;
    Ymat(1,length(Y)/2)=-Ym;
    Ymat(length(Y)/2,1)=-Ym;

    
%setting up magnet flux sources
for counter=1:length(Ymat)
    phi(counter,1)=-(-1)^counter*2*phi_r;
end

%solving the equations
Um=inv(Ymat)*phi; %Um=magnetisk potensiale;



for i=1:length(Ymat)-1    %calculating coil flux linkeages
coil(i,step)=Um(i)*Y(i*2)+Um(i+1)*Y(i*2+1);
end
coil(length(Ymat),step)=Um(length(Ymat))*Y(length(Ymat)*2)+Y(1)*Um(1);
tann(step)=Um(1)*Y(1)/(base^2*m_length*s_scaling); % avreage flux density in stator tooth number one
end